@@ -1,6 +1,6 @@
 /*******************************************************************************
  * #-------------------------------------------------------------------------------
- * # Copyright (c) 2003-2016 IPI PAN.
+ * # dmLab 2003-2019
  * # All rights reserved. This program and the accompanying materials
  * # are made available under the terms of the GNU Public License v3.0
  * # which accompanies this distribution, and is available at
@@ -15,11 +15,6 @@
  * # Algorithm 'SLIQ' developed by Mariusz Gromada
  * # R Package developed by Michal Draminski & Julian Zubek
  * #-------------------------------------------------------------------------------
- * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
- * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
- * # "Monte Carlo feature selection for supervised classification", 
- * # BIOINFORMATICS 24(1): 110-117 (2008)
- * #-------------------------------------------------------------------------------
  *******************************************************************************/
 package dmLab.classifier.adx.complex;
 
@@ -422,7 +417,7 @@ public class ComplexSet
             //System.out.println(" DEBUG ####### toThrow:"+toThrow);
 			int throwArray[]=new int[minQualityIDs.size()];
     		ArrayUtils arrayUtils = new ArrayUtils();
-    		arrayUtils.randomFill(throwArray,toThrow,1,0);
+    		arrayUtils.randomSelect(throwArray,toThrow,1,0);
 
 			for(int i=0;i<throwArray.length;i++)
 				if(throwArray[i]==1)
